@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Block Attachments
-    Version ........ 0.6
+    Version ........ 0.7
     Purpose ........ Allows an admin to block any types of attachments
 
 *******************************************************************************/
@@ -28,7 +28,7 @@
       if (in_array(strtolower($username),$excluded)) return;
       if (in_array($ext,$blocked)) {
          bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
-         if ($Args[1]['download link']['text'] == _("download")) {
+         if ($Args[1]['download link']['text'] == _("download") || $Args[1]['download link']['text'] == _("Download")) {
             textdomain('block_attach');
             $Args[1]['download link']['text'] = _("File Blocked");
             $Args[6] = SM_PATH . "plugins/block_attach/blocked.php";
@@ -38,7 +38,7 @@
       }
 
       if (in_array($ext,$warning)) {
-         if ($Args[1]['download link']['text'] == _("download")) {
+         if ($Args[1]['download link']['text'] == _("download") || $Args[1]['download link']['text'] == _("Download")) {
             $Args[6] = SM_PATH . "plugins/block_attach/blocked.php?startMessage=$Args[2]&&passed_id=$Args[3]&mailbox=$Args[4]&ent_id=$Args[5]";
             $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/blocked.php?startMessage=$Args[2]&&passed_id=$Args[3]&mailbox=$Args[4]&ent_id=$Args[5]";
          }
